pub struct GitHub;Trait Implementations
Sourceimpl SimpleOAuthProvider for GitHub
impl SimpleOAuthProvider for GitHub
The authorization endpoint of the provider
Sourcefn default_scopes(&self) -> &'static [&'static str]
fn default_scopes(&self) -> &'static [&'static str]
Default scopes used when building the provider’s authorization URL.
Sourcefn token_auth_method(&self) -> TokenAuthMethod
fn token_auth_method(&self) -> TokenAuthMethod
How the OAuth client should authenticate to the provider’s token endpoint.
Sourceimpl UserInfoProvider for GitHub
impl UserInfoProvider for GitHub
Sourcefn user_info_url(&self) -> &str
fn user_info_url(&self) -> &str
The URL to fetch the user info from the provider
Sourcefn user_info_headers(
&self,
_credentials: &OAuthCredentials,
) -> Vec<(String, String)>
fn user_info_headers( &self, _credentials: &OAuthCredentials, ) -> Vec<(String, String)>
Additional headers to send when making user info requests to the provider