pub struct Google;Trait Implementations
Sourceimpl SimpleOAuthProvider for Google
impl SimpleOAuthProvider for Google
Sourcefn default_scopes(&self) -> &'static [&'static str]
fn default_scopes(&self) -> &'static [&'static str]
Minimum scopes needed to get basic profile info (id, name, username). Email is not included
by default - the user can specify that by passing
in custom scopes when calling
client.authorize_url()The authorization endpoint of the provider
Sourcefn user_info_url(&self) -> &str
fn user_info_url(&self) -> &str
The URL to fetch the user info from the provider