pub struct Microsoft;Trait Implementations
Sourceimpl SimpleOAuthProvider for Microsoft
impl SimpleOAuthProvider for Microsoft
The authorization endpoint of the provider
Sourcefn default_scopes(&self) -> &'static [&'static str]
fn default_scopes(&self) -> &'static [&'static str]
Default scopes used when building the provider’s authorization URL.
Sourcefn token_auth_method(&self) -> TokenAuthMethod
fn token_auth_method(&self) -> TokenAuthMethod
How the OAuth client should authenticate to the provider’s token endpoint.
Sourceimpl UserInfoProvider for Microsoft
impl UserInfoProvider for Microsoft
Sourcefn user_info_url(&self) -> &str
fn user_info_url(&self) -> &str
The URL to fetch the user info from the provider
Sourcefn extract_user_info(&self, val: Value) -> Result<UserInfo, Error>
fn extract_user_info(&self, val: Value) -> Result<UserInfo, Error>
Extract the user data from the provider’s user response
Sourcefn user_info_headers(
&self,
_credentials: &OAuthCredentials,
) -> Vec<(String, String)>
fn user_info_headers( &self, _credentials: &OAuthCredentials, ) -> Vec<(String, String)>
Additional headers to send when making user info requests to the provider