pub struct UserInfo {
pub id: String,
pub name: Option<String>,
pub username: Option<String>,
pub email: Option<String>,
pub email_verified: Option<bool>,
pub avatar_url: Option<String>,
pub groups: Option<Vec<String>>,
}Expand description
User info returned by the OAuth provider
Fields
id: StringThe ID of the user at the OAuth provider
name: Option<String>The user’s display name
username: Option<String>The user’s username
email: Option<String>The user’s email. Will likely not be included unless you add the proper email scope for the provider.
⚠️ Do not rely on this for identifying the user. Use the id and the name of the provider.
email_verified: Option<bool>Whether the user’s email is verified. Not all providers return this in the user info.
avatar_url: Option<String>The URL of the user’s picture/avatar
groups: Option<Vec<String>>The groups the user is a part of. Only included for certain OIDC providers.