TokenAuthMethod

Type Alias TokenAuthMethod 

pub type TokenAuthMethod = AuthType;
The token auth method (basic auth or request body)

Aliased Type

pub enum TokenAuthMethod {
    RequestBody,
    BasicAuth,
}

Variants



RequestBody

The client_id and client_secret (if set) will be included as part of the request body.



BasicAuth

The client_id and client_secret will be included using the basic auth authentication scheme.