pub struct GitLab;Trait Implementations
Sourceimpl SimpleOAuthProvider for GitLab
impl SimpleOAuthProvider for GitLab
The authorization endpoint of the provider
Sourcefn user_info_url(&self) -> &str
fn user_info_url(&self) -> &str
The URL to fetch the user info from the provider
Sourcefn default_scopes(&self) -> &'static [&'static str]
fn default_scopes(&self) -> &'static [&'static str]
Minimum scopes needed to get basic profile info (id, name, username). Email is not included
by default - the user can specify that by passing
in custom scopes when calling
client.authorize_url()Auto Trait Implementations
impl Freeze for GitLab
impl RefUnwindSafe for GitLab
impl Send for GitLab
impl Sync for GitLab
impl Unpin for GitLab
impl UnsafeUnpin for GitLab
impl UnwindSafe for GitLab