Type Alias TokenAuthMethod
Source pub type TokenAuthMethod = AuthType;
The token auth method (basic auth or request body)
pub enum TokenAuthMethod {
RequestBody,
BasicAuth,
}
The client_id and client_secret (if set) will be included as part of the request body.
The client_id and client_secret will be included using the basic auth authentication scheme.